"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const default_metadata_generators_1 = require("./default-metadata-generators");
(0, vitest_1.describe)("defaultGenerateIdentifierType", () => {
    (0, vitest_1.it)("generates correct identifier type", () => {
        const result = (0, default_metadata_generators_1.defaultGenerateIdentifierType)(...[
            { name: "thing_id", type: { kind: "base", fullName: "text" } },
            { name: "my_things", schemaName: "public" },
            { typeMap: {} },
        ]);
        (0, vitest_1.expect)(result).toMatchObject({
            declarationType: "typeDeclaration",
            comment: ["Identifier type for public.my_things"],
            name: "MyThingsThingId",
            typeDefinition: ["unknown & { __brand: 'MyThingsThingId' }"],
        });
    });
    (0, vitest_1.it)("generates correct identifier type with special characters", () => {
        const result = (0, default_metadata_generators_1.defaultGenerateIdentifierType)(...[
            { name: "special_col!'.", type: { kind: "base", fullName: "text" } },
            { name: "special_table!'.", schemaName: "special_schema!'." },
            { typeMap: {} },
        ]);
        (0, vitest_1.expect)(result).toMatchObject({
            declarationType: "typeDeclaration",
            comment: ["Identifier type for special_schema!'..special_table!'."],
            name: "SpecialTableSpecialCol",
            typeDefinition: ["unknown & { __brand: 'SpecialTableSpecialCol' }"],
        });
    });
});
