"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const recase_1 = require("@kristiandupont/recase");
const toPascalCase = (0, recase_1.recase)(null, "pascal");
/** Used for identifiers. If the name has symbols or is illegal Typescript, strip out symbols and make it PascalCase. */
// NB: A wider set of things than are accepted by this function are valid identifiers in TypeScript (see https://stackoverflow.com/a/9337047). However, this works well for our purposes.
const escapeIdentifier = (name) => {
    const trimmed = name.trim();
    let isLegalIdentifier = true;
    if (!/^[$A-Z_a-z][\w$]*$/.test(trimmed)) {
        isLegalIdentifier = false;
    }
    try {
        new Function(`const ${trimmed} = 1;`);
    }
    catch {
        isLegalIdentifier = false;
    }
    if (isLegalIdentifier) {
        return trimmed;
    }
    const snaked = trimmed.replaceAll(/[^$A-Z_a-z]/g, "_").replaceAll(/_+/g, "_");
    const result = toPascalCase(snaked);
    if (result.length === 0) {
        throw new Error(`Invalid and unsalvageable identifier: ${name}`);
    }
    return result;
};
exports.default = escapeIdentifier;
